"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getInstallationScript = getInstallationScript;
exports.getStopScript = getStopScript;
exports.start = start;
exports.stop = stop;
var _debug = _interopRequireDefault(require("debug"));
var _child_process = require("child_process");
var _postgres = _interopRequireDefault(require("postgres"));
var _os = require("os");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const debug = (0, _debug.default)('postgres-local');
const PD_TEMP_DATA_PATH = `/tmp/postgres-local}`;
async function start(options) {
  const {
    seedPath,
    version = 14,
    port = 5555,
    includeInstallation = false
  } = options;
  const url = `postgres://localhost:${port}/postgres`;
  try {
    (0, _child_process.spawnSync)(getInstallationScript({
      version,
      port,
      includeInstallation
    }), {
      stdio: 'inherit',
      shell: true,
      env: {
        ...process.env,
        HOME: '/root'
      }
    });
    debug('Connecting to postgres...');
    const sql = (0, _postgres.default)(url);
    debug('Postgres available!');
    process.env.PSQL = url;
    if (seedPath !== null && seedPath !== void 0 && seedPath.length) {
      debug('Found seed file, seeding...');
      await sql.file(seedPath);
      debug('Seed done available!');
    }
    return url;
  } catch (e) {
    console.error(e);
    throw e;
  }
}
function stop({
  version = 14
}) {
  (0, _child_process.spawnSync)(getStopScript({
    version
  }), {
    stdio: 'inherit',
    shell: true
  });
}
function getInstallationScript({
  version = 14,
  port = 5555,
  includeInstallation = false
}) {
  switch ((0, _os.platform)()) {
    case 'darwin':
      {
        const installation = includeInstallation ? `brew install postgresql@${version};` : '';
        return `
       ${installation}
       mkdir -p ${PD_TEMP_DATA_PATH}/data;
       initdb -D ${PD_TEMP_DATA_PATH}/data;
       pg_ctl -D ${PD_TEMP_DATA_PATH}/data -o "-F -p ${port}" -l ${PD_TEMP_DATA_PATH}/logfile start;
      `;
      }
    case 'win32':
      {
        throw new Error('Unsupported OS, try run on OS X or Linux');
      }
    default:
      {
        // eslint-disable-next-line
        const installation = includeInstallation ? `sudo apt update; sudo apt install postgresql-${version};` : '';
        return `
        ${installation}
        sudo -u postgres mkdir -p ${PD_TEMP_DATA_PATH}/data;
        sudo -u postgres /usr/lib/postgresql/${version}/bin/initdb -D ${PD_TEMP_DATA_PATH}/data;
        sudo -u postgres /usr/lib/postgresql/${version}/bin/pg_ctl -o "-F -p ${port}" -D ${PD_TEMP_DATA_PATH}/data -l ${PD_TEMP_DATA_PATH}/logfile start;
        sudo -u postgres createuser -p ${port} -s $(whoami);
        sudo -u postgres createdb -p ${port} $(whoami);
      `;
      }
  }
}
function getStopScript({
  version = 14
}) {
  switch ((0, _os.platform)()) {
    case 'darwin':
      {
        return `
         pg_ctl stop -D ${PD_TEMP_DATA_PATH}/data
         rm -rf ${PD_TEMP_DATA_PATH}
      `;
      }
    default:
      {
        return `
        sudo -u postgres /usr/lib/postgresql/${version}/bin/pg_ctl stop -D ${PD_TEMP_DATA_PATH}/data
        sudo -u postgres rm -rf ${PD_TEMP_DATA_PATH}
      `;
      }
  }
}